@@ -16,6 +16,8 @@
 __docformat__ = "restructuredtext"
 
 # import standard packages
+import codecs
+from cStringIO import StringIO
 
 # import Zope3 interfaces
 from z3c.json.interfaces import IJSONWriter
@@ -27,7 +29,7 @@ from ztfy.scheduler.browser.interfaces import ITaskPropertiesTarget, \
 from ztfy.scheduler.interfaces import ISchedulerTask, ISchedulerTaskHistoryInfo, \
                                       ISchedulerCronTaskInfo, ISchedulerDateTaskInfo, \
                                       ISchedulerLoopTaskInfo, ISchedulerTaskInfo
-from ztfy.skin.interfaces import IDefaultView, IContainedDefaultView
+from ztfy.skin.interfaces import IDefaultView, IContainedDefaultView, IDialogEditFormButtons
 from ztfy.skin.layer import IZTFYBackLayer
 
 # import Zope3 packages
@@ -37,6 +39,8 @@ from z3c.table.column import Column, FormatterColumn, GetAttrColumn
 from zope.component import adapts, queryMultiAdapter, getUtility
 from zope.i18n import translate
 from zope.interface import implements, Interface
+from zope.schema import Bool
+from zope.schema.fieldproperty import FieldProperty
 from zope.traversing import namespace
 from zope.traversing import api as traversing_api
 from zope.traversing.browser import absoluteURL
@@ -153,8 +157,9 @@ class SchedulerTaskExecuteForm(DialogEditForm):
     def ajaxEdit(self):
         self.context.launch()
         writer = getUtility(IJSONWriter)
-        return writer.write({ 'output': u'OK',
-                              'message': translate(_("Task successfully scheduled. Execution will start in 5 seconds."), context=self.request) })
+        return writer.write({'output': u'OK',
+                             'message': translate(_("Task successfully scheduled. Execution will start in 5 seconds."),
+                                                  context=self.request)})
 
 
 class BaseTaskScheduleForm(DialogEditForm):
@@ -190,6 +195,43 @@ class LoopTaskScheduleForm(BaseTaskScheduleForm):
     fields = field.Fields(ISchedulerLoopTaskInfo)
 
 
+# Task debug-mode run form
+
+class SchedulerTaskDebugModeRunForm(DialogEditForm):
+    """Scheduler task run form in debug mode"""
+
+    help = _("Running a task in debug mode can to useful during development, as you can apply breakpoints.")
+
+    fields = field.Fields(Interface)
+
+    def getContent(self):
+        return object()
+
+    def updateActions(self):
+        super(SchedulerTaskDebugModeRunForm, self).updateActions()
+        if 'dialog_submit' in self.actions:
+            self.actions['dialog_submit'].title = _("Run task")
+
+    def applyChanges(self, data):
+        report = codecs.getwriter('utf-8')(StringIO())
+        self.context.run(report)
+        return report.getvalue()
+
+    def getOutput(self, writer, parent, changes=()):
+        if changes:
+            return writer.write({'output': u'MESSAGE',
+                                 'message': changes})
+        else:
+            return writer.write({'output': self.changes_output})
+
+
+class SchedulerTaskDebugModeRunFormMenu(DialogMenuItem):
+    """Scheduler task debug-mode run menu item"""
+
+    title = _(" :: Run task (debug mode)...")
+    target = SchedulerTaskDebugModeRunForm
+
+
 #
 # Task tables columns
 #
@@ -198,7 +240,7 @@ class TaskTitleColumn(Column):
 
     header = _("Title")
     weight = 10
-    cssClasses = { 'td': 'title' }
+    cssClasses = {'td': 'title'}
 
     def renderCell(self, item):
         title = item.title
@@ -295,7 +337,7 @@ class TaskHistoryStatusColumn(GetAttrColumn):
     weight = 30
 
     attrName = 'status'
-    cssClasses = { 'td': 'centered' }
+    cssClasses = {'td': 'centered'}
 
 
 # Task history view
@@ -310,7 +352,7 @@ class TaskHistoryView(ContainerBaseView):
 
     legend = _("Task execution history")
 
-    cssClasses = { 'table': 'history' }
+    cssClasses = {'table': 'history'}
     sortOn = None
 
     @property
